.. :changelog:

Release History
---------------

0.2.0 (2017-10-15)
++++++++++++++++++

* snifty now maintains more information on the chefs it's sending packets to
* Added time to ARPChef dumpling payload
* Added time of last lookup to DNSLookupChef
* Changed time format to float milliseconds
* Minor code style and documentation tweaks

0.1.0 (2016-11-05)
++++++++++++++++++

* First actual github release (0.0.1 was really just the first git commit)

0.0.1 (2016-04-22)
++++++++++++++++++

* Initial release
